require "import"
import "android.widget.*"
import "android.view.*"
import "android.content.Intent"
import "android.net.Uri"
import "android.view.KeyEvent"

activity.setTitle("Helping the Blind")
activity.setTheme(android.R.style.Theme_DeviceDefault_Light_NoActionBar)

viewHistory = {}

function setViewWithHistory(view)
    table.insert(viewHistory, view)
    activity.setContentView(view)
end

function onKeyDown(keyCode, event)
    if keyCode == KeyEvent.KEYCODE_BACK then
        if #viewHistory > 1 then
            table.remove(viewHistory)
            local previousView = viewHistory[#viewHistory]
            activity.setContentView(previousView)
            return true
        end
    end
    return false
end

function openYouTubeChannel()
    local url = "https://youtube.com/@creativitygatewayfortheblind?si=umpO0IMgsbcA-69Y"
    local intent = Intent(Intent.ACTION_VIEW, Uri.parse(url))
    intent.setPackage("com.google.android.youtube")
    activity.startActivity(intent)
end

function showHelp()
    local helpText = {
        "مرحبا بكم في أداة مساعدة المكفوفين، الأداة الشاملة والحصرية لمساعدة المكفوفين.",
        "تقدم هذه الأداة العديد من الأشياء المفيدة للمكفوفين.",
        "مثل الأذكار والقرآن الكريم والأدعية",
        "والكثير من الأشياء الجيدة الأخرى.",
        "تابعوا قناتنا على يوتيوب.",
        "في زر القائمة الجانبية للأداة.",
        "لنستمر في تحسين وتطوير وإضافة المزيد من الميزات للأداة.",
        "شاكرين تعاونكم معنا.",
        "مطور الأداة محمد العراقي"
    }

    local helpLayout = {
        ScrollView,
        layout_width = "fill",
        layout_height = "fill",
        {
            LinearLayout,
            orientation = "vertical",
            layout_width = "fill",
            layout_height = "wrap",
            padding = "16dp",
            {
                Button,
                text = "رجوع",
                layout_width = "match_parent",
                layout_height = "wrap_content",
                onClick = function()
                    showMenu()
                end,
            },
            {
                TextView,
                text = "المساعدة",
                textSize = "22sp",
                textColor = "#000000",
                layout_width = "wrap_content",
                layout_height = "wrap_content",
                layout_marginTop = "16dp",
            },
        }
    }

    for i, line in ipairs(helpText) do
        table.insert(helpLayout[2], {
            TextView,
            text = line,
            textSize = "18sp",
            textColor = "#000000",
            layout_width = "fill",
            layout_height = "wrap_content",
            layout_marginTop = "8dp",
        })
    end

    setViewWithHistory(loadlayout(helpLayout))
end

function showSurah(surahName, verses)
    local surahLayout = {
        ScrollView,
        layout_width = "fill",
        layout_height = "fill",
        {
            LinearLayout,
            orientation = "vertical",
            layout_width = "fill",
            layout_height = "wrap",
            padding = "16dp",
            {
                Button,
                text = "رجوع",
                layout_width = "match_parent",
                layout_height = "wrap_content",
                onClick = function()
                    showQuran()
                end,
            },
            {
                TextView,
                text = surahName,
                textSize = "24sp",
                textColor = "#000000",
                layout_width = "wrap_content",
                layout_height = "wrap_content",
                layout_marginTop = "16dp",
            },
        }
    }

    for i, verse in ipairs(verses) do
        table.insert(surahLayout[2], {
            TextView,
            text = verse,
            textSize = "18sp",
            textColor = "#000000",
            layout_width = "fill",
            layout_height = "wrap_content",
            layout_marginTop = "8dp",
        })
    end

    setViewWithHistory(loadlayout(surahLayout))
end

function showQuran()
    local quranLayout = {
        LinearLayout,
        orientation = "vertical",
        layout_width = "fill",
        layout_height = "fill",
        padding = "16dp",
        {
            Button,
            text = "رجوع",
            layout_width = "match_parent",
            layout_height = "wrap_content",
            onClick = function()
                setViewWithHistory(loadlayout(mainLayout))
            end,
        },
        {
            TextView,
            text = "القرآن الكريم",
            textSize = "22sp",
            textColor = "#000000",
            layout_width = "wrap_content",
            layout_height = "wrap_content",
            layout_marginTop = "10dp",
        },
        {
            Button,
            text = "سورة الفاتحة",
            layout_width = "match_parent",
            layout_height = "wrap_content",
            layout_marginTop = "10dp",
            onClick = function()
                local verses = {
                    "بِسْمِ اللَّهِ الرَّحْمَٰنِ الرَّحِيمِ",
                    "الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ",
                    "الرَّحْمَٰنِ الرَّحِيمِ",
                    "مَالِكِ يَوْمِ الدِّينِ",
                    "إِيَّاكَ نَعْبُدُ وَإِيَّاكَ نَسْتَعِينُ",
                    "اهْدِنَا الصِّرَاطَ الْمُسْتَقِيمَ",
                    "صِرَاطَ الَّذِينَ أَنْعَمْتَ عَلَيْهِمْ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلَا الضَّالِّينَ"
                }
                showSurah("سورة الفاتحة", verses)
            end,
        },
    }
    setViewWithHistory(loadlayout(quranLayout))
end

function showAzkar(title, azkarList)
    local azkarLayout = {
        ScrollView,
        layout_width = "fill",
        layout_height = "fill",
        {
            LinearLayout,
            orientation = "vertical",
            layout_width = "fill",
            layout_height = "wrap",
            padding = "16dp",
            {
                Button,
                text = "رجوع",
                layout_width = "match_parent",
                layout_height = "wrap_content",
                onClick = function()
                    showAzkarMenu()
                end,
            },
            {
                TextView,
                text = title,
                textSize = "22sp",
                textColor = "#000000",
                layout_width = "wrap_content",
                layout_height = "wrap_content",
                layout_marginTop = "16dp",
            },
        }
    }

    for i, zikr in ipairs(azkarList) do
        table.insert(azkarLayout[2], {
            TextView,
            text = zikr,
            textSize = "18sp",
            textColor = "#000000",
            layout_width = "fill",
            layout_height = "wrap_content",
            layout_marginTop = "8dp",
        })
    end

    setViewWithHistory(loadlayout(azkarLayout))
end

function showAzkarMenu()
    local azkarMenuLayout = {
        LinearLayout,
        orientation = "vertical",
        layout_width = "fill",
        layout_height = "fill",
        padding = "16dp",
        {
            Button,
            text = "رجوع",
            layout_width = "match_parent",
            layout_height = "wrap_content",
            onClick = function()
                setViewWithHistory(loadlayout(mainLayout))
            end,
        },
        {
            TextView,
            text = "الأذكار",
            textSize = "22sp",
            textColor = "#000000",
            layout_width = "wrap_content",
            layout_height = "wrap_content",
            layout_marginTop = "10dp",
        },
        {
            Button,
            text = "أذكار الصباح",
            layout_width = "match_parent",
            layout_height = "wrap_content",
            layout_marginTop = "10dp",
            onClick = function()
                local azkarSabah = {
                    "اللّهـمَّ أَنْتَ رَبِّـي لا إلهَ إلاّ أَنْتَ، خَلَقْتَني وَأَنا عَبْـدُك ...",
                    "رَضيـتُ بِاللهِ رَبّـاً، وَبِالإسْلامِ ديـناً ...",
                    "اللّهُـمَّ ما أَصْبَـحَ بي مِـن نِعْـمَةٍ ...",
                    "اللّهُـمَّ عافِـني في بَدَنـي ...",
                    "اللّهُـمَّ إني أسألـكَ العَـفْوَ وَالعـافِـية ...",
                    "اللّهُـمَّ إني أعـوذُ بِكَ مِـن الكُـفر ...",
                    "اللّهُـمَّ أَنتَ رَبِّـي، لا إلهَ إلاّ أَنتَ ...",
                    "أَصْـبَـحْـنا وَأَصْـبَـحَ المُـلكُ لله ...",
                    "اللّهُـمَّ إني أَصْبَـحْتُ أُشْـهِدُكَ ...",
                    "اللّهُـمَّ ما أَصْبَـحَ بي مِـن نِعْـمَةٍ ...",
                    "اللّهُـمَّ اجعلني من التوابين ...",
                    "اللّهُـمَّ ارزقني حبك ...",
                    "أستغفر الله العظيم الذي لا إله إلا هو ...",
                    "اللهم صل وسلم على نبينا محمد ...",
                    "اللهم إني أعوذ بك من الهم والحزن ..."
                }
                showAzkar("أذكار الصباح", azkarSabah)
            end,
        },
        {
            Button,
            text = "أذكار المساء",
            layout_width = "match_parent",
            layout_height = "wrap_content",
            layout_marginTop = "10dp",
            onClick = function()
                local azkarMasa = {
                    "اللّهُـمَّ أَنْتَ رَبِّـي لا إلهَ إلاّ أَنْتَ ...",
                    "رَضيـتُ بِاللهِ رَبّـاً، وَبِالإسْلامِ ديـناً ...",
                    "اللّهُـمَّ ما أَمْسى بي مِـن نِعْـمَةٍ ...",
                    "اللّهُـمَّ عافِـني في بَدَنـي ...",
                    "اللّهُـمَّ إني أسألـكَ العَـفْوَ وَالعـافِـية ...",
                    "اللّهُـمَّ إني أعـوذُ بِكَ مِـن الكُـفر ...",
                    "اللّهُـمَّ أَنتَ رَبِّـي، لا إلهَ إلاّ أَنتَ ...",
                    "أَمْسَـيْنا وَأَمْسَـى المُـلكُ لله ...",
                    "اللّهُـمَّ إني أَمْسَـيْتُ أُشْـهِدُكَ ...",
                    "اللّهُـمَّ اجعلني من التوابين ...",
                    "اللّهُـمَّ ارزقني حبك ...",
                    "أستغفر الله العظيم الذي لا إله إلا هو ...",
                    "اللهم صل وسلم على نبينا محمد ...",
                    "اللهم إني أعوذ بك من الهم والحزن ...",
                    "اللهم إني أسألك الجنة وأعوذ بك من النار ..."
                }
                showAzkar("أذكار المساء", azkarMasa)
            end,
        },
    }
    setViewWithHistory(loadlayout(azkarMenuLayout))
end

function showMenu()
    local menuLayout = {
        LinearLayout,
        orientation = "vertical",
        layout_width = "fill",
        layout_height = "fill",
        padding = "16dp",
        {
            Button,
            text = "رجوع",
            layout_width = "match_parent",
            layout_height = "wrap_content",
            onClick = function()
                setViewWithHistory(loadlayout(mainLayout))
            end,
        },
        {
            Button,
            text = "قناتنا على يوتيوب",
            layout_width = "match_parent",
            layout_height = "wrap_content",
            layout_marginTop = "10dp",
            onClick = function()
                openYouTubeChannel()
            end,
        },
        {
            Button,
            text = "المساعدة",
            layout_width = "match_parent",
            layout_height = "wrap_content",
            layout_marginTop = "10dp",
            onClick = function()
                showHelp()
            end,
        },
    }
    setViewWithHistory(loadlayout(menuLayout))
end

mainLayout = {
    LinearLayout,
    orientation = "vertical",
    layout_width = "fill",
    layout_height = "fill",
    background = "#FFFFFF",
    padding = "16dp",
    {
        Button,
        text = "Open menu",
        layout_width = "match_parent",
        layout_height = "wrap_content",
        onClick = function()
            showMenu()
        end,
    },
    {
        TextView,
        text = "Helping the Blind",
        textSize = "24sp",
        textColor = "#000000",
        layout_width = "wrap_content",
        layout_height = "wrap_content",
        layout_marginTop = "16dp",
    },
    {
        Button,
        text = "القرآن الكريم",
        layout_width = "match_parent",
        layout_height = "wrap_content",
        layout_marginTop = "16dp",
        onClick = function()
            showQuran()
        end,
    },
    {
        Button,
        text = "الأذكار",
        layout_width = "match_parent",
        layout_height = "wrap_content",
        layout_marginTop = "16dp",
        onClick = function()
            showAzkarMenu()
        end,
    },
}

setViewWithHistory(loadlayout(mainLayout))

